@@ -128,7 +128,7 @@ register jsonrpc => sub {
             };
             my $error = $@;
 
-            debug("[handeled_jsonrpc_call($method_name)] ", $result);
+            debug("[handled_jsonrpc_call($method_name)] ", flatten_data($result));
             if ($error) {
                 push @responses, jsonrpc_error_response(
                     $request->{id},
@@ -144,7 +144,7 @@ register jsonrpc => sub {
                     $request->{id},
                     $result->as_jsonrpc_error->{error}
                 );
-                next
+                next;
             }
             elsif (blessed($result)) {
                 $result = flatten_data($result);
@@ -202,12 +202,13 @@ sub jsonrpc_error_response {
 }
 
 sub build_dispatcher_from_pod {
-    my ($pkgs) = @_;
+    my ($pkgs, $endpoint) = @_;
     debug("[build_dispatcher_from_pod]");
 
     return dispatch_table_from_pod(
+        plugin   => 'jsonrpc',
         packages => $pkgs,
-        label    => 'jsonrpc',
+        endpoint => $endpoint,
     );
 }
 
@@ -216,7 +217,7 @@ sub build_dispatcher_from_config {
     debug("[build_dispatcher_from_config] $endpoint");
 
     return dispatch_table_from_config(
-        key      => 'jsonrpc',
+        plugin   => 'jsonrpc',
         config   => $config,
         endpoint => $endpoint,
     );
